from datetime import datetime, timedelta

from django import template
from django.utils import timezone

register = template.Library()


@register.filter(name="duration")
def duration(value):
    secs = int(value.total_seconds())
    hours = secs // (60 * 60)
    if hours > 0:
        secs = secs % (hours * 60 * 60)
    minutes = secs // 60
    return f"{hours}:{minutes:02d}h"


@register.filter(name="night_from_to")
def night_from_to(value):
    if not isinstance(value, datetime):
        raise ValueError("value must be a datetime object")

    value = value.astimezone(timezone.get_current_timezone())

    if value.hour < 6:
        date = value.date()
        days = ["Mo", "Di", "Mi", "Do", "Fr", "Sa", "So"]
        return f"{days[(date-timedelta(days=1)).weekday()]}\u2192{days[date.weekday()]}"

    return ""
