import requests
from bs4 import BeautifulSoup
from django.db import models

# Create your models here.


class Page(models.Model):
    REDIRECT = "redirect"
    REGULAR = "regular"
    REMOTE_CONTENT = "remote"
    KIND_CHOICES = [
        (REDIRECT, "Redirect"),
        (REGULAR, "Regular page"),
        (REMOTE_CONTENT, "Remote content"),
    ]

    url = models.fields.SlugField(unique=True)
    content = models.TextField()
    visible = models.BooleanField(default=True)
    title = models.CharField(blank=True, max_length=200)
    kind = models.CharField(choices=KIND_CHOICES, default=REGULAR, max_length=8)
    show_in_footer_nav = models.BooleanField(default=True)
    show_in_main_nav = models.BooleanField(default=False)

    # Fields for remote content
    remote_url = models.URLField(blank=True, null=True)
    import_error = models.BooleanField(default=False)

    def __str__(self):
        if self.kind == Page.REDIRECT:
            return f"{self.get_kind_display()} {self.url} => {self.content}"
        elif self.kind == Page.REMOTE_CONTENT:
            return f"{self.get_kind_display()} {self.url} from {self.remote_url}"
        return f"{self.get_kind_display()} {self.url}"

    def fetch_remote_content(self):
        if self.kind != self.REMOTE_CONTENT or not self.remote_url:
            return

        try:
            response = requests.get(self.remote_url)
            response.raise_for_status()

            soup = BeautifulSoup(response.text, "html.parser")
            body_content = soup.find("body")

            if body_content:
                self.content = f"<div class='content'>{str(body_content)}</div>"
                self.import_error = False
        except (requests.RequestException, Exception):
            self.import_error = True

        self.save()
